@@ -10,7 +10,8 @@ class DjangoRamConfig(AppConfig):
         from django.utils.module_loading import autodiscover_modules
 
         autodiscover_modules("roles")
-        from django_ram.definition import create_roles
+        from django_ram.definition import clean_removed_roles, create_roles
 
         post_migrate.connect(create_roles, sender=self)
+        post_migrate.connect(clean_removed_roles, sender=self)
         return super().ready()
