@@ -8,7 +8,7 @@ REQUIRED_ROLE_DEFNITION_ATTRIBUTES = {"name"}
 ROLE_DEFINITION_ATTRIBUTES = {*REQUIRED_ROLE_DEFNITION_ATTRIBUTES, "description"}
 
 
-def create_roles(sender, plan, **kwargs):
+def create_roles(sender, plan=None, **kwargs):
     """Create :class:`~django_ram.models.Role`\s from :class:`~django_ram.definition.RoleDefinition`\s."""
     unapplying = plan and any([unapply for _, unapply in plan])
     if unapplying:
@@ -29,7 +29,7 @@ def create_roles(sender, plan, **kwargs):
             role.save(update_fields=role_attributes)
 
 
-def clean_removed_roles(sender, plan, **kwargs):
+def clean_removed_roles(sender, plan=None, **kwargs):
     """Delete or mark as inactive all roles that do not have a definition (role definition has been removed).
 
     If the ``DELETE_REMOVED_ROLES`` setting is enabled, delete all roles without a corresponding
